View source: R/f_chain_indices.R
| chgeowalsh | R Documentation |
This function returns a value (or vector of values) of the monthly chained geometric Walsh price index
chgeowalsh(data, start, end, interval = FALSE)
data |
The user's data frame with information about sold products. It must contain columns: |
start |
The base period (as character) limited to the year and month, e.g. "2020-03". |
end |
The research period (as character) limited to the year and month, e.g. "2020-04". |
interval |
A logical value indicating whether the function is to compare the research period defined by |
The function returns a value (or vector of values) of the monthly chained geometric Walsh price index depending on the interval parameter. If the interval parameter is set to TRUE, the function returns a vector of price index values without dates. To get information about both price index values and corresponding dates, please see functions: price_indices or final_index. The function does not take into account aggregating over outlets or product subgroups (to consider these types of aggregating, please use the final_index function).
Walsh, C.M. (1901). The Measurement of General Exchange Value. New York: Macmillan and Co., p.202
Walsh, C.M. (1921). The Problem of Estimation. London: P.S. King & Son, p.97
chgeowalsh(sugar, start="2018-12", end="2019-04")
chgeowalsh(milk, start="2018-12", end="2020-01", interval=TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.