View source: R/f_chain_indices.R
| chybmd | R Documentation |
This function returns a value (or vector of values) of the monthly chained Young-Balk-Mehrhoff Dikhanov price index
chybmd(data, start, end, interval = FALSE)
data |
The user's data frame with information about sold products. It must contain columns: |
start |
The base period (as character) limited to the year and month, e.g. "2020-03". |
end |
The research period (as character) limited to the year and month, e.g. "2020-04". |
interval |
A logical value indicating whether the function is to compare the research period defined by |
The function returns a value (or vector of values) of the monthly chained Young-Balk-Mehrhoff Dikhanov (YBMD) price index depending on the interval parameter. If the interval parameter is set to TRUE, the function returns a vector of price index values without dates. To get information about both price index values and corresponding dates, please see functions: price_indices or final_index. The function does not take into account aggregating over outlets or product subgroups (to consider these types of aggregating, please use the final_index function). This function returns values identical to those of the chain Dikhanov and chain BMW indices (three different names for this index are used in the literature).
Mehrhoff, J.(2007). A linear approximation to the Jevons index. In: Von der Lippe (2007): Index Theory and Price Statistics, Peter Lang: Berlin, Germany.
(2018). Harmonised Index of Consumer Prices (HICP). Methodological Manual. Publication Office of the European union, Luxembourg.
Dikhanov, Y., (2024). A New Elementary Index Number. Paper presented at the 18th Meeting of the Ottawa Group on Price Indices, Ottawa, Canada.
Białek, J., Dikhanov, Y. (2026). Properties of the Young-Balk-Mehrhoff-Dikhanov elementary price index. Paper presented at the 19th Meeting of the Ottawa Group on Price Indices, Warsaw, Poland.
chybmd(sugar, start="2018-12", end="2019-04")
chybmd(milk, start="2018-12", end="2020-01", interval=TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.