View source: R/f_bilateral_indices.R
| hlc | R Documentation |
This function returns a value (or vector of values) of the bilateral harmonic log-change price index.
hlc(data, start, end, interval = FALSE)
data |
The user's data frame with information about sold products. It must contain columns: |
start |
The base period (as character) limited to the year and month, e.g. "2020-03". |
end |
The research period (as character) limited to the year and month, e.g. "2020-04". |
interval |
A logical value indicating whether the function is to compare the research period defined by |
The function returns a value (or vector of values) of the bilateral harmonic log-change price index (HLC), i.e., the log-change index constructed using weights equal to the harmonic mean of expenditure shares (rather than the arithmetic mean used in the Törnqvist index). If the interval parameter is set to TRUE, the function returns a vector of price index values without dates. To get information about both price index values and corresponding dates, please see functions: price_indices or final_index. The function does not take into account aggregating over outlets or product subgroups (to consider these types of aggregating, please use the final_index function).
hlc(sugar, start="2018-12", end="2019-12")
hlc(milk, start="2018-12", end="2020-01", interval=TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.